# Install package documentation into a binary package staging area
#
# Copyright (C) 2012 Patrick McDermott
#
# This file is part of opkbuild.
#
# opkbuild is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# opkbuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with opkbuild.  If not, see <http://www.gnu.org/licenses/>.

set -eu

install_docs()
{
	local srcs="${1}"
	local dest="${2}"
	local data_doc_dir="${3}"
	shift 3
	local src=

	for src in ${srcs}; do
		if [ -f "${src}" ]; then
			if ! mkdir -p -- "$(dirname -- \
					"${data_doc_dir}/./${dest}")"; then
				ob_error "$(ob_get_msg 'cant_make_doc_dir')"
				return 1
			fi
			if ! cp -R -- "${src}" "${data_doc_dir}/${dest}"; then
				ob_error "$(ob_get_msg 'cant_cp_doc_file')" \
					"${src}"
				return 1
			fi
		elif [ -d "${src}" ]; then
			if ! mkdir -p -- "$(dirname -- \
					"${data_doc_dir}/./${dest}")"; then
				ob_error "$(ob_get_msg 'cant_make_doc_dir')"
				return 1
			fi
			if ! cp -R -- "${src}/." "${data_doc_dir}/${dest}"; then
				ob_error "$(ob_get_msg 'cant_cp_doc_file')" \
					"${src}"
				return 1
			fi
		fi
	done

	return 0
}

main()
{
	local doc_pkg=
	local doc_pkg_doc_dir=
	local pkg=
	local doc_dir=
	local data_doc_dir=
	local srcs=
	local dest=

	if ! ob_set_text_domain 'opkbuild'; then
		printf '%s: Error: Failed to load locale messages\n' \
			"${0##*/}" >&2
		return 1
	fi

	ob_init_package '..' || return 1

	if ! doc_pkg="$(ob_get_doc_package)"; then
		ob_error "$(ob_get_msg 'cant_get_doc_pkg')"
		return 1
	fi
	doc_pkg_doc_dir="$(ob_get_system_path 'package-docs' \
		"$(ob_qualify_package_name "${doc_pkg}" "${OPK_HOST_ARCH}")" \
		"${OPK_BINARY_VERSION}")"

	for pkg in ${OPK_PACKAGES_REDUCED}; do
		doc_dir="$(ob_get_system_path 'package-docs' \
			"$(ob_qualify_package_name "${pkg}" \
				"${OPK_HOST_ARCH}")" \
			"${OPK_BINARY_VERSION}")"
		data_doc_dir="${pkg}.data/${doc_dir%/}"
		if [ x"${pkg}" = x"${doc_pkg}" ]; then
			if [ -d "${data_doc_dir}" ]; then
				ob_info "$(ob_get_msg \
					'docs_already_installed')" "${pkg}"
			else
				ob_info "$(ob_get_msg 'installing_docs')" \
					"${pkg}"
				if ! mkdir -p -- "${data_doc_dir}"; then
					ob_error "$(ob_get_msg \
						'cant_make_doc_dir')"
					return 1
				fi
				while read srcs dest; do
					install_docs "${srcs}" "${dest}" \
						"${data_doc_dir}" || return 1
				done <<-EOF
					$(ob_get_doc_files)
					EOF
			fi
		else
			if [ -L "${data_doc_dir}" ]; then
				ob_info "$(ob_get_msg 'docs_already_linked')" \
					"${pkg}"
			else
				ob_info "$(ob_get_msg 'linking_docs')" "${pkg}"
				if ! mkdir -p -- "$(dirname -- \
						"${data_doc_dir}")"; then
					ob_error "$(ob_get_msg \
						'cant_make_doc_dir')"
					return 1
				fi
				if ! ln -s -- "${doc_pkg_doc_dir}" \
						"${data_doc_dir}"; then
					ob_error "$(ob_get_msg \
						'cant_ln_doc_dir')"
					return 1
				fi
			fi
		fi
	done

	return 0
}
